from sinta_scraper.affil_scraper import affil, affils, affil_authors
from sinta_scraper.author_scraper import author, authors
from sinta_scraper.comm_svc_scraper import author_comm_services
from sinta_scraper.dept_scraper import dept_authors, depts_authors
from sinta_scraper.ipr_scraper import author_ipr
from sinta_scraper.research_scraper import author_researches
from sinta_scraper.scholar_documents_scraper import author_scholar_docs
from sinta_scraper.scopus_documents_scraper import author_scopus_docs
from sinta_scraper.wos_documents_scraper import author_wos_docs
